@@ -107,7 +107,7 @@ static inline const char* findHashStringString(hash_string_string *ht, const cha
 
 static inline void addHashStringString(hash_string_string **ht, const char *key, const char *val)
 {
-  hash_string_string *v = (hash_string_string*) calloc(1, sizeof(hash_string_string));
+  hash_string_string *v = (hash_string_string*) calloc(1, sizeof(hash_string_string)); /* FIXME this isn't always freed correctly */
   v->id=strdup(key);
   v->val=strdup(val);
   HASH_ADD_KEYPTR( hh, *ht, v->id, strlen(v->id), v );
@@ -383,7 +383,8 @@ static void read_var_attribute_real(omc_ScalarVariable *v, REAL_ATTRIBUTE *attri
   read_value_real(findHashStringStringEmpty(v,"min"), &(attribute->min), REAL_MIN);
   read_value_real(findHashStringStringEmpty(v,"max"), &(attribute->max), REAL_MAX);
   read_value_string(findHashStringStringEmpty(v,"unit"), &unit);
-  attribute->unit = mmc_mk_scon_persist(unit);
+  attribute->unit = mmc_mk_scon_persist(unit); /* this function returns a copy, so unit can be freed */
+  free((char*)unit);
 
   infoStreamPrint(LOG_DEBUG, 0, "Real %s(start=%g, fixed=%s, %snominal=%g%s, min=%g, max=%g)", findHashStringString(v,"name"), attribute->start, (attribute->fixed)?"true":"false", (attribute->useNominal)?"":"{", attribute->nominal, attribute->useNominal?"":"}", attribute->min, attribute->max);
 }
@@ -410,7 +411,8 @@ static void read_var_attribute_string(omc_ScalarVariable *v, STRING_ATTRIBUTE *a
 {
   const char *start = NULL;
   read_value_string(findHashStringStringEmpty(v,"start"), &start);
-  attribute->start = mmc_mk_scon_persist(start);
+  attribute->start = mmc_mk_scon_persist(start); /* this function returns a copy, so start can be freed */
+  free((char*)start);
 
   infoStreamPrint(LOG_DEBUG, 0, "String %s(start=%s)", findHashStringString(v,"name"), MMC_STRINGDATA(attribute->start));
 }
@@ -479,7 +481,7 @@ void read_input_xml(MODEL_DATA* modelData,
     char buf[BUFSIZ] = {0};
     do
     {
-      size_t len = fread(buf, 1, sizeof(buf), file);
+      size_t len = omc_fread(buf, 1, sizeof(buf), file, 1);
       done = len < sizeof(buf);
       if(XML_STATUS_ERROR == XML_Parse(parser, buf, len, done))
       {
@@ -510,7 +512,7 @@ void read_input_xml(MODEL_DATA* modelData,
      ARE WE READING THE OLD XML FILE?? */
   guid = findHashStringStringNull(mi.md,"guid");
   if (NULL==guid) {
-     warningStreamPrint(LOG_STDOUT, 0, "The Model GUID: %s is not set in file: %s",
+    warningStreamPrint(LOG_STDOUT, 0, "The Model GUID: %s is not set in file: %s",
         modelData->modelGUID,
         filename);
   } else if (strcmp(modelData->modelGUID, guid)) {
@@ -657,7 +659,7 @@ void read_input_xml(MODEL_DATA* modelData,
   infoStreamPrint(LOG_DEBUG, 1, "read xml file for real alias vars");
   for(i=0; i<modelData->nAliasReal; i++)
   {
-    const char *aliasTmp;
+    const char *aliasTmp = NULL;
     read_var_info(*findHashLongVar(mi.rAli,i), &modelData->realAlias[i].info);
 
     read_value_string(findHashStringStringNull(*findHashLongVar(mi.rAli,i),"alias"), &aliasTmp);
@@ -679,6 +681,8 @@ void read_input_xml(MODEL_DATA* modelData,
       modelData->realAlias[i].filterOutput = 1;
     }
 
+    free((char*)aliasTmp);
+    aliasTmp = NULL;
     read_value_string(findHashStringStringNull(*findHashLongVar(mi.rAli,i),"aliasVariable"), &aliasTmp);
 
     it = findHashStringLongPtr(mapAlias, aliasTmp);
@@ -699,6 +703,7 @@ void read_input_xml(MODEL_DATA* modelData,
                 modelData->realAlias[i].info.name,
                 modelData->realAlias[i].nameID,
                 modelData->realAlias[i].aliasType ? ((modelData->realAlias[i].aliasType==2) ? "time" : "real parameters") : "real variables");
+    free((char*)aliasTmp);
   }
   messageClose(LOG_DEBUG);
 
@@ -708,7 +713,7 @@ void read_input_xml(MODEL_DATA* modelData,
   infoStreamPrint(LOG_DEBUG, 1, "read xml file for integer alias vars");
   for(i=0; i<modelData->nAliasInteger; i++)
   {
-    const char *aliasTmp;
+    const char *aliasTmp = NULL;
     read_var_info(*findHashLongVar(mi.iAli,i), &modelData->integerAlias[i].info);
 
     read_value_string(findHashStringStringNull(*findHashLongVar(mi.iAli,i),"alias"), &aliasTmp);
@@ -730,6 +735,8 @@ void read_input_xml(MODEL_DATA* modelData,
       infoStreamPrint(LOG_DEBUG, 0, "filtering variable %s due to HideResult annotation", modelData->integerAlias[i].info.name);
       modelData->integerAlias[i].filterOutput = 1;
     }
+    free((char*)aliasTmp);
+    aliasTmp = NULL;
     read_value_string(findHashStringString(*findHashLongVar(mi.iAli,i),"aliasVariable"), &aliasTmp);
 
     it = findHashStringLongPtr(mapAlias, aliasTmp);
@@ -748,6 +755,7 @@ void read_input_xml(MODEL_DATA* modelData,
                 modelData->integerAlias[i].info.name,
                 modelData->integerAlias[i].nameID,
                 modelData->integerAlias[i].aliasType?"integer parameters":"integer variables");
+    free((char*)aliasTmp);
   }
   messageClose(LOG_DEBUG);
 
@@ -757,7 +765,7 @@ void read_input_xml(MODEL_DATA* modelData,
   infoStreamPrint(LOG_DEBUG, 1, "read xml file for boolean alias vars");
   for(i=0; i<modelData->nAliasBoolean; i++)
   {
-    const char *aliasTmp;
+    const char *aliasTmp = NULL;
     read_var_info(*findHashLongVar(mi.bAli,i), &modelData->booleanAlias[i].info);
 
     read_value_string(findHashStringString(*findHashLongVar(mi.bAli,i),"alias"), &aliasTmp);
@@ -779,6 +787,8 @@ void read_input_xml(MODEL_DATA* modelData,
       infoStreamPrint(LOG_DEBUG, 0, "filtering variable %s due to HideResult annotation", modelData->booleanAlias[i].info.name);
       modelData->booleanAlias[i].filterOutput = 1;
     }
+    free((char*)aliasTmp);
+    aliasTmp = NULL;
     read_value_string(findHashStringString(*findHashLongVar(mi.bAli,i),"aliasVariable"), &aliasTmp);
 
     it = findHashStringLongPtr(mapAlias, aliasTmp);
@@ -797,6 +807,7 @@ void read_input_xml(MODEL_DATA* modelData,
                 modelData->booleanAlias[i].info.name,
                 modelData->booleanAlias[i].nameID,
                 modelData->booleanAlias[i].aliasType ? "boolean parameters" : "boolean variables");
+    free((char*)aliasTmp);
   }
   messageClose(LOG_DEBUG);
 
@@ -806,7 +817,7 @@ void read_input_xml(MODEL_DATA* modelData,
   infoStreamPrint(LOG_DEBUG, 1, "read xml file for string alias vars");
   for(i=0; i<modelData->nAliasString; i++)
   {
-    const char *aliasTmp;
+    const char *aliasTmp = NULL;
     read_var_info(*findHashLongVar(mi.sAli,i), &modelData->stringAlias[i].info);
 
     read_value_string(findHashStringString(*findHashLongVar(mi.sAli,i),"alias"), &aliasTmp);
@@ -828,6 +839,8 @@ void read_input_xml(MODEL_DATA* modelData,
       modelData->stringAlias[i].filterOutput = 1;
     }
 
+    free((char*)aliasTmp);
+    aliasTmp = NULL;
     read_value_string(findHashStringString(*findHashLongVar(mi.sAli,i),"aliasVariable"), &aliasTmp);
 
     it = findHashStringLongPtr(mapAlias, aliasTmp);
@@ -846,6 +859,7 @@ void read_input_xml(MODEL_DATA* modelData,
                 modelData->stringAlias[i].info.name,
                 modelData->stringAlias[i].nameID,
                 modelData->stringAlias[i].aliasType ? "string parameters" : "string variables");
+    free((char*)aliasTmp);
   }
   messageClose(LOG_DEBUG);
 
@@ -860,7 +874,7 @@ static inline void read_value_string(const char *s, const char **str)
     warningStreamPrint(LOG_SIMULATION, 0, "error read_value, no data allocated for storing string");
     return;
   }
-  *str = strdup(s);
+  *str = strdup(s); /* memory is allocated here, must be freed by the caller */
 }
 
 /* reads double value from a string */
@@ -950,7 +964,7 @@ void doOverride(omc_ModelInput *mi, MODEL_DATA *modelData, const char *override,
     /* read override values from file */
     infoStreamPrint(LOG_SOLVER, 0, "read override values from file: %s", overrideFile);
 
-    infile = fopen(overrideFile, "rb");
+    infile = omc_fopen(overrideFile, "rb");
     if (0==infile) {
       throwStreamPrint(NULL, "simulation_input_xml.c: could not open the file given to -overrideFile=%s", overrideFile);
     }
@@ -961,7 +975,7 @@ void doOverride(omc_ModelInput *mi, MODEL_DATA *modelData, const char *override,
     line[0] = '\0';
     fseek(infile, 0L, SEEK_SET);
     errno = 0;
-    if (1 != fread(line, n, 1, infile)) {
+    if (1 != omc_fread(line, n, 1, infile, 0)) {
       free(line);
       throwStreamPrint(NULL, "simulation_input_xml.c: could not read overrideFile %s: %s", overrideFile, strerror(errno));
     }
@@ -1005,6 +1019,11 @@ void doOverride(omc_ModelInput *mi, MODEL_DATA *modelData, const char *override,
       while (p) {
         // split it key = value => map[key]=value
         value = strchr(p, '=');
+
+        if (!value) {
+          throwStreamPrint(NULL, "Invalid format for value of override flag: %s", override);
+        }
+
         if (*value == '\0') {
           warningStreamPrint(LOG_SOLVER, 0, "failed to parse override string %s", p);
           p = strtok(NULL, "!");
@@ -1035,6 +1054,11 @@ void doOverride(omc_ModelInput *mi, MODEL_DATA *modelData, const char *override,
       while (p) {
         // split it key = value => map[key]=value
         value = strchr(p, '=');
+
+        if (!value) {
+          throwStreamPrint(NULL, "Invalid format for value of override flag: %s", override);
+        }
+
         if (*value == '\0') {
           warningStreamPrint(LOG_SOLVER, 0, "failed to parse override string %s", p);
           p = strtok(NULL, "!");
