@@ -51,6 +51,7 @@
 #include "meta/meta_modelica.h"
 #include "simulation/solver/epsilon.h"
 #include "simulation/solver/external_input.h"
+#include "synchronous.h"
 #include "linearSystem.h"
 #include "sym_solver_ssc.h"
 #include "irksco.h"
@@ -419,8 +420,8 @@ int freeSolverData(DATA* data, SOLVER_INFO* solverInfo)
           solverInfo->solverMethod == S_TRAPEZOID ||
           solverInfo->solverMethod == S_IMPRUNGEKUTTA)
   {
-    /* free work arrays */
-    freeKinOde(data, solverInfo);
+    /* free  work arrays */
+    freeKinOde((KINODE*)solverInfo->solverData);
   }
   else if(solverInfo->solverMethod == S_IDA)
   {
@@ -456,6 +457,7 @@ int initializeModel(DATA* data, threadData_t *threadData, const char* init_initM
 {
   TRACE_PUSH
   int retValue = 0;
+  int usedLocal = 0;
 
   SIMULATION_INFO *simInfo = data->simulationInfo;
 
@@ -490,10 +492,13 @@ int initializeModel(DATA* data, threadData_t *threadData, const char* init_initM
     }
     if (!retValue)
     {
-      if (data->simulationInfo->homotopySteps == 0)
+      if (data->simulationInfo->homotopySteps == 0) {
         infoStreamPrint(LOG_SUCCESS, 0, "The initialization finished successfully without homotopy method.");
-      else
-        infoStreamPrint(LOG_SUCCESS, 0, "The initialization finished successfully with %d homotopy steps.", data->simulationInfo->homotopySteps);
+      }
+      else {
+        usedLocal = data->callback->useHomotopy == 0 || data->callback->useHomotopy == 3;
+        infoStreamPrint(LOG_SUCCESS, 0, "The initialization finished successfully with %d %shomotopy steps.", data->simulationInfo->homotopySteps, usedLocal? "local ":"");
+      }
     }
 
     success = 1;
@@ -606,11 +611,8 @@ int finishSimulation(DATA* data, threadData_t *threadData, SOLVER_INFO* solverIn
 
       infoStreamPrint(LOG_STATS, 1, "solver: %s", SOLVER_METHOD_NAME[solverInfo->solverMethod]);
       infoStreamPrint(LOG_STATS, 0, "%5d steps taken", solverInfo->solverStats[0]);
-
       infoStreamPrint(LOG_STATS, 0, "%5d calls of functionODE", solverInfo->solverStats[1]);
-
       infoStreamPrint(LOG_STATS, 0, "%5d evaluations of jacobian", solverInfo->solverStats[2]);
-
       infoStreamPrint(LOG_STATS, 0, "%5d error test failures", solverInfo->solverStats[3]);
       infoStreamPrint(LOG_STATS, 0, "%5d convergence test failures", solverInfo->solverStats[4]);
       infoStreamPrint(LOG_STATS, 0, "%gs time of jacobian evaluation", rt_accumulated(SIM_TIMER_JACOBIAN));
@@ -921,7 +923,7 @@ static int rungekutta_step_ssc(DATA* data, threadData_t *threadData, SOLVER_INFO
   modelica_real* stateDerOld = sDataOld->realVars + nx;
   double t = sDataOld->timeValue;
   const double targetTime = t + solverInfo->currentStepSize;
-  const short isMaxStepSizeSet = (short) omc_flagValue[FLAG_MAX_STEP_SIZE];
+  const short isMaxStepSizeSet = omc_flagValue[FLAG_MAX_STEP_SIZE] != NULL;
   const double maxStepSize = isMaxStepSizeSet ? atof(omc_flagValue[FLAG_MAX_STEP_SIZE]) : -1;
 #if defined(_MSC_VER)
   /* handle stupid compilers */
