@@ -241,11 +241,6 @@ namespace IAEX
    if(cells.empty())
    {
      return;
-      //Empty pasteboard.
-      //application()->clearPasteboard();
-      //application()->addToPasteboard(c->currentCell());
-
-      //c->removeCurrentCell();
    }
    else
    {
@@ -511,6 +506,7 @@ namespace IAEX
    else
    {
       document()->clearSelection(); //Notice
+      application()->clearPasteboard(); // HACK: clear pasteboard as this cell might be referenced in it
 
       vector<Cell *>::iterator i = cells.begin();
       for(;i != cells.end();++i)
